@@ -1,5 +1,3 @@
-import json
-
 import elasticsearch as elasticsearch
 
 from crawlab.utils.config import get_data_source
@@ -7,12 +5,15 @@ from crawlab.utils.config import get_data_source
 
 def get_client() -> elasticsearch.Elasticsearch:
     ds = get_data_source()
-    base_auth = None
+    http_auth = None
     if ds.get('username') is not None and ds.get('password') is not None:
-        base_auth = (ds.get('username'), ds.get('password'))
+        http_auth = f'{ds.get("username")}:{ds.get("password")}'
     return elasticsearch.Elasticsearch(
-        hosts=[{'host': ds.get('host'), 'port': ds.get('port')}],
-        basic_auth=base_auth,
+        hosts=[{
+            'host': ds.get('host'),
+            'port': ds.get('port'),
+            'http_auth': http_auth,
+        }],
     )
 
 
